/** Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */

package org.dive4elements.river.artifacts.sinfo.flood_duration;

import java.util.HashSet;
import java.util.Set;

import org.dive4elements.artifactdatabase.state.ArtifactAndFacet;
import org.dive4elements.artifactdatabase.state.Facet;
import org.dive4elements.artifacts.CallContext;
import org.dive4elements.river.artifacts.common.AbstractCalculationResult;
import org.dive4elements.river.exports.DiagramGenerator;
import org.dive4elements.river.exports.DurationCurveGenerator;
import org.dive4elements.river.exports.XYChartGenerator;
import org.dive4elements.river.exports.process.DefaultProcessor;
import org.dive4elements.river.themes.ThemeDocument;

/**
 * Processor to generate the facet and data series of a flood duration curve
 *
 * @author Matthias Schäfer
 *
 */
public final class FloodDurationCurveProcessor extends DefaultProcessor {

    private static final String FACET_FLOOD_DURATION_W = "duration_curve.w";

    private static final String FACET_FLOOD_DURATION_Q = "duration_curve.q";

    private static final Set<String> HANDLED_FACET_TYPES = new HashSet<>();

    static {
        HANDLED_FACET_TYPES.add(FACET_FLOOD_DURATION_W);
        HANDLED_FACET_TYPES.add(FACET_FLOOD_DURATION_Q);
    }

    public static Facet createFloodDurationWCurveFacet(final CallContext context, final String hash, final String id, final AbstractCalculationResult result,
            final int facetIndex, final int resultIndex, final String description) {

        return new FloodDurationCurveFacet(FACET_FLOOD_DURATION_W, description);
    }

    public static Facet createFloodDurationQCurveFacet(final CallContext context, final String hash, final String id, final AbstractCalculationResult result,
            final int facetIndex, final int resultIndex, final String description) {

        return new FloodDurationCurveFacet(FACET_FLOOD_DURATION_Q, description);
    }

    /**
     * Processes data to generate a chart.
     */
    @Override
    public void doOut(final XYChartGenerator generator, final ArtifactAndFacet bundle, final ThemeDocument theme, final boolean visible, final int index) {

    }

    @Override
    public final String getAxisLabel(final DiagramGenerator generator) {
        return generator.msg(DurationCurveGenerator.I18N_YAXIS_LABEL_W);
    }

    @Override
    public final boolean canHandle(final String facettype) {
        return HANDLED_FACET_TYPES.contains(facettype);
    }
}